// Copyright 2013 Canonical Ltd.  This software is licensed under the
// GNU Lesser General Public License version 3 (see the file COPYING).

// Define the various role sizes and their attributes.

package gwacl

// RoleSize is a representation of the data available in the Azure
// documentation here:
// http://msdn.microsoft.com/en-us/library/windowsazure/dn197896.aspx and
// pricing from here:
// http://www.windowsazure.com/en-us/pricing/details/virtual-machines/
type RoleSize struct {
    Name             string
    CpuCores         uint64
    Mem              uint64 // In MB
    OSDiskSpaceCloud uint64 // In GB
    OSDiskSpaceVirt  uint64 // In GB
    MaxDataDisks     uint64 // 1TB each
    Cost             uint64 // US ¢ (cents) per hour
}

var RoleSizes = []RoleSize{
    {
        Name:             "ExtraSmall",
        CpuCores:         1,  // shared
        Mem:              768,
        OSDiskSpaceCloud: 19,
        OSDiskSpaceVirt:  20,
        MaxDataDisks:     1,
        Cost:             2,
    }, {
        Name:             "Small",
        CpuCores:         1,
        Mem:              1792,
        OSDiskSpaceCloud: 224,
        OSDiskSpaceVirt:  70,
        MaxDataDisks:     2,
        Cost:             6,
    }, {
        Name:             "Medium",
        CpuCores:         2,
        Mem:              3584,
        OSDiskSpaceCloud: 489,
        OSDiskSpaceVirt:  135,
        MaxDataDisks:     4,
        Cost:             12,
    }, {
        Name:             "Large",
        CpuCores:         4,
        Mem:              7168,
        OSDiskSpaceCloud: 999,
        OSDiskSpaceVirt:  285,
        MaxDataDisks:     8,
        Cost:             24,
    }, {
        Name:             "ExtraLarge",
        CpuCores:         8,
        Mem:              14336,
        OSDiskSpaceCloud: 2039,
        OSDiskSpaceVirt:  65,
        MaxDataDisks:     16,
        Cost:             48,
    }, {
        Name:             "A6",
        CpuCores:         4,
        Mem:              28672,
        OSDiskSpaceCloud: 999,
        OSDiskSpaceVirt:  285,
        MaxDataDisks:     8,
        Cost:             82,
    }, {
        Name:             "A7",
        CpuCores:         8,
        Mem:              57344,
        OSDiskSpaceCloud: 2039,
        OSDiskSpaceVirt:  65,
        MaxDataDisks:     16,
        Cost:             164,
    },
}
